==> leechcraft-0.3.80_rc20101221.tar.bz2: leechcraft-0.3.80_rc20101221/src/plugins/tabpp/leechcraft_tabpp_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>LeechCraft::Plugins::TabPP::Core</name>
    <message>
        <location filename="core.cpp" line="281"/>
        <source>unknown</source>
        <translation>неизвестно</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::TabPP::Plugin</name>
    <message>
        <location filename="tabpp.cpp" line="72"/>
        <source>Enhances user experience with tabs.</source>
        <translation>Улучшает взаимодействие пользователя с вкладками.</translation>
    </message>
    <message>
        <location filename="tabpp.cpp" line="123"/>
        <source>Show tab switcher</source>
        <translation>Показать переключатель табов</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::TabPP::TabPPWidget</name>
    <message>
        <location filename="tabppwidget.cpp" line="44"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
</context>
<context>
    <name>tabppsettings</name>
    <message>
        <location filename="dummy.cpp" line="2"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="3"/>
        <source>Behavior</source>
        <translation>Поведение</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="4"/>
        <source>Show on action hover</source>
        <translation>Показывать при наведении курсора на действие</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="5"/>
        <source>Focus on the tab list after show</source>
        <translation>Фокус на списке табов при показе</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="6"/>
        <source>Hide on Ctrl+Enter</source>
        <translation>Скрывать по Ctrl+Enter</translation>
    </message>
</context>
</TS>

==> leechcraft-0.4.75_rc20110524.tar.bz2: leechcraft-0.4.75_rc20110524/src/plugins/tabpp/leechcraft_tabpp_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>LeechCraft::Plugins::TabPP::Core</name>
    <message>
        <location filename="core.cpp" line="281"/>
        <source>unknown</source>
        <translation>неизвестно</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::TabPP::Plugin</name>
    <message>
        <location filename="tabpp.cpp" line="72"/>
        <source>Enhances user experience with tabs.</source>
        <translation>Улучшает взаимодействие пользователя с вкладками.</translation>
    </message>
    <message>
        <location filename="tabpp.cpp" line="123"/>
        <source>Show tab switcher</source>
        <translation>Показать переключатель вкладок</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::TabPP::TabPPWidget</name>
    <message>
        <location filename="tabppwidget.cpp" line="44"/>
        <source>F9</source>
        <translation>F9</translation>
    </message>
</context>
<context>
    <name>tabppsettings</name>
    <message>
        <location filename="dummy.cpp" line="2"/>
        <source>Settings</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="3"/>
        <source>Behavior</source>
        <translation>Поведение</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="4"/>
        <source>Show on action hover</source>
        <translation>Показывать при наведении курсора на действие</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="5"/>
        <source>Focus on the tab list after show</source>
        <translation>Фокус на списке вкладок при показе</translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="6"/>
        <source>Hide on Ctrl+Enter</source>
        <translation>Скрывать по Ctrl+Enter</translation>
    </message>
</context>
</TS>
